@@ -1,5 +1,6 @@
 import getpass
 import json
+import os
 from pathlib import Path
 
 
@@ -10,7 +11,10 @@ def login_args_configuration(sub_parser):
 
 
 def login(_):
-    path = Path.home().joinpath(".deep-chain").joinpath("config")
+    path = Path.home().joinpath(".deep-chain")
+    path.mkdir(exist_ok=True)
+    path = path.joinpath("config")
+
     data = {}
     with open(path, "w+") as config_file:
         try:
